@@ -1,4 +1,4 @@
-from collections import Iterable
+from collections.abc import Iterable
 
 from .inspection import InspectionMixin
 
@@ -8,7 +8,7 @@ class SerializeMixin(InspectionMixin):
 
     __abstract__ = True
 
-    def to_dict(self, nested=False, hybrid_attributes=False):
+    def to_dict(self,nested = False, hybrid_attributes = False, exclude = None):
         """Return dict object with model's data.
 
         :param nested: flag to return nested relationships' data if true
@@ -17,7 +17,13 @@ class SerializeMixin(InspectionMixin):
         :return: dict
         """
         result = dict()
-        for key in self.columns:
+
+        if exclude is None:
+             view_cols = self.columns
+        else :
+             view_cols = filter(lambda e: e not in exclude, self.columns)
+
+        for key in view_cols :
             result[key] = getattr(self, key)
 
         if hybrid_attributes:
